function VaR = finrisk_VaRcf(alpha_vec,muL,stdL,skewL,kurtL)
% FINRISK_VARCF calculates a Cornish-Fisher expansion for the Value at Risk
%   given the relevant moments of the loss variable
%  
% Syntax: VaR = finrisk_VaRcf(alpha_vec,muL,stdL,skewL,kurtL) 
%
% Inputs:
%   alpha_vec - vector of significance levels (exceedance probabilities)
%   muL       - mean
%   stdL      - standard deviation
%   skewL     - skewness
%   kurtL     - kurtosis (not excess kurtosis)
% 
% See also: finrisk_VaRcf_data 
%
% author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

Nu = norminv(1-alpha_vec);
xkurtL = kurtL - 3;
CFu = Nu ...
    + 1/6 * (Nu.^2 - 1) *skewL ...
    + 1/24 * (Nu.^3 - 3*Nu) * xkurtL ...
    - 1/36 * (2 * Nu.^3 - 5 * Nu) * skewL^2;
VaR(:,1) = muL + stdL * CFu;


end