function VaR = finrisk_VaRmix(alpha_vec,p_vec,mu_vec,sigma_vec)
% FINRISK_VARMIX calculates the Value at Risk under the assumption that the 
%   loss distribution is a mixture of normals
%  
% Syntax: VaR = FINRISK_VARMIX(alpha_vec,p_vec,mu_vec,sigma_vec) 
%
% Inputs:
%   alpha_vec - vector of significance levels (exceedance probabilities)
%   p_vec     - component weights of the mixture distributions
%   mu_vec    - vector of component means
%   sigma_vec - vector of component standard deviations
% 
% See also: finrisk_VaRmix_data, gmdistribution
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

K = length(p_vec);

% calc unconditional moments to dermine starting vals based on the
% normal VaR
mu_uc = 0;
var_uc = 0;

for k=1:K
    mu_uc = mu_uc + mu_vec(k) * p_vec(k);
    var_uc = var_uc + (sigma_vec(k)^2 + mu_vec(k)^2) * p_vec(k);
end
var_uc = var_uc - mu_uc^2;

VaR = zeros(length(alpha_vec),1);
for i=1:length(alpha_vec)
    alpha_i = alpha_vec(i);
    start_q = finrisk_VaRpar(alpha_vec(i),'n',[mu_uc,sqrt(var_uc)]);
    optset = optimset('Display','off','TolX',1e-15,'TolFun',1e-15);
    VaR(i,1) = fsolve(@target_fun,start_q,optset);
end

    function val = target_fun(q)
        Fq  = 0;
        for k2=1:K
            Fq = Fq + p_vec(k2) * normcdf(q,mu_vec(k2),sigma_vec(k2));
        end
        val = Fq - (1-alpha_i);
    end
end