function VaR = finrisk_VaRmix_data(alpha_vec,l_vec,nrep_est)
% FINRISK_VARMIX_DATA calculates the Value at Risk assuming a mixture of
% normal distributions for the loss variable based on sample data
%  
% Syntax: 
%   VaR = FINRISK_VARMIX_DATA(alpha_vec,l_vec) 
%   VaR = FINRISK_VARMIX_DATA(alpha_vec,l_vec,nrep_est) 
%
% Inputs: 
%   alpha_vec - significance levels (exceedance probabilities)
%   l_vec     - vector with loss data
%   nrep_est  - number of restarts for the EM algorithm
%
% See also finrisk_VaRmix, finrisk_est_mix
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

if nargin < 3
    nrep_est = [];
end
[p_vec,mu_vec,sigma_vec] = finrisk_est_mix(2,l_vec,nrep_est);
VaR = finrisk_VaRmix(alpha_vec,p_vec,mu_vec,sigma_vec);
    
end