function VaR = finrisk_VaRpot(alpha_vec,xi,beta,u,Nu,T)
% FINRISK_VARPOT calculates Peaks-over-threshold(POT)-based VaR estimates
%  
% Syntax: VaR = FINRISK_VARPOT(alpha_vec,xi,beta,u,Nu,T) 
%
% Inputs:
%   alpha_vec - vector of probability levels (exceedance probabilities)
%   xi        - shape parameter of GPD
%   beta      - scale parameter of GPD
%   u         - threshold
%   Nu        - number of peaks (threshold exceedances) 
%   T         - total number of iid observations
% 
% See also: finrisk_VaRpot_data, finrisk_est_pot 
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

VaR(:,1) = u + beta/xi * ((Nu./(alpha_vec * T)).^xi - 1);

end