function ES=finrisk_EScf(alpha_vec,muL,stdL,skewL,kurtL)
% FINRISK_ESCF calculates the expected shortfall based on a Cornish-Fisher 
%   expansion given mean, standard deviation, skewness and kurtosis
%  
% Syntax: ES = FINRISK_ESCF(alpha_vec,muL,stdL,skewL,kurtL)
%
% Inputs:
%   alpha_vec - vector of significance levels
%   muL       - mean
%   stdL      - standard deviation
%   skewL     - skewness
%   kurtL     - kurtosis
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

version = 2;
    
xkurtL = kurtL - 3;
N=norminv(1-alpha_vec);


switch version
    case 1
        C1=N+(1/6)*(N.^2 -1).*skewL + (1/24)*(N.^3 - 3.*N)*xkurtL - (1/36).* (2 * N.^3-5 .* N)*skewL^2;
        lam_cf=(normpdf(C1)./alpha_vec).*(1+((C1.^3)*skewL)/6 + (kurt/24)*((C1p.^4) - 2*(C1p.^2) -1));
    case 2
        lam_cf = normpdf(N,0,1)./alpha_vec ...
            .* (1-xkurtL/24-skewL^2/4+skewL/6*N + (xkurtL/24-skewL^2/18)*N.^2) - skewL/6;
    otherwise
        error('weitere Darstellungen nicht implementiert');
end
ES(:,1) = muL + stdL * lam_cf;

end