function ES = finrisk_ESmix(alpha_vec,p_vec,mu_vec,sigma_vec)
% FINRISK_ESMIX calculates the Expected Shortfall for a loss variable with 
% a normal mixture distribution given the relevant parameters
%
% Syntax: ES = FINRISK_ESMIX(alpha_vec,p_vec,mu_vec,sigma_vec)
%
% Inputs:
%   alpha_vec - vector of significance levels
%   p_vec     - component weights
%   mu_vec    - vector of component means
%   sigma_vec - vector of component standard deviations
%
% See also: finrisk_ESmix_data, finrisk_VaRmix
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

if size(alpha_vec,1)==1 && size(alpha_vec,2)>1
    alpha_vec = alpha_vec';
end

K = length(p_vec);

VaR = finrisk_VaRmix(alpha_vec,p_vec,mu_vec,sigma_vec);
sumES = zeros(length(alpha_vec),1);

for k=1:K
    muk  = mu_vec(k);
    sigk = sigma_vec(k);
    pk   = p_vec(k);
    Qk   = (VaR-muk)./sigk;
    ncdfqk = normcdf(Qk);
    npdfqk = normpdf(Qk);
    sumES = sumES + pk * (muk .* (1-ncdfqk) + npdfqk * sigk);
end
ES(:,1) = sumES ./ alpha_vec;

end