function ES = finrisk_ESmix_data(alpha_vec,l_vec,nrep_est)
% FINRISK_ESMIX_DATA calculates the Expected Shortfall for a loss variable 
%       with a normal mixture distribution
%
% Syntax:
%   ES = FINRISK_ESMIX_DATA(alpha_vec,l_vec)
%   ES = FINRISK_ESMIX_DATA(alpha_vec,l_vec,nrep_est)
%
% Inputs:
%   alpha_vec - vector of probability level(s)
%   l_vec     - vector of input data
%   nrep_est  - number of times to repeat estimation algorithm with
%               different start values
%
% See also: finrisk_ESmix, finrisk_est_mix
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

if nargin < 3
    nrep_est = [];
end

[p_vec,mu_vec,sigma_vec,gmdist] = finrisk_est_mix(2,l_vec,nrep_est);
ES = finrisk_ESmix(alpha_vec,p_vec,mu_vec,sigma_vec);
end