function ES = finrisk_ESpot(VaR_vec,xi,beta,u)
% FINRISK_ESPOT calculates the Expected Shortfall (ES) using the Peaks-over-threshold(POT) 
%       method given the necessary parameters
%  
% Syntax: ES = FINRISK_ESPOT(VaR_vec,xi,beta,u) 
%
% Inputs:
%   VaR_vec - vector of POT-VaR estimates obtained by finrisk_VaRpot
%   xi      - shape parameter of GPD
%   beta    - scale parameter of GPD
%   u       - threshold
% 
% See also: finrisk_ESpot_data, finrisk_VARpot, finrisk_VaRpot_data
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

ES(:,1) = VaR_vec .* (1/(1-xi) + (beta - xi * u)./((1-xi) .* VaR_vec));

end