function [ES,VaR] = finrisk_ESpot_data(alpha_vec,l_vec)
% FINRISK_ESPOT_DATA calculates the Expected Shortfall (ES) using the 
%       Peaks-over-threshold (POT) method given a loss vector l_vec  and the
%       signficance levels in alpha_vec
%  
% Syntax: [ES,VaR] = FINRISK_ESPOT_DATA(alpha_vec,l_vec) 
%
% See also: finrisk_VaRpot, finrisk_est_pot, finrisk_ESpot
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

if max(alpha_vec) > 0.1
    error('alpha too large for u');
end
[xi,beta,u,Nu,T] = finrisk_est_pot(l_vec);
VaR = finrisk_VaRpot(alpha_vec,xi,beta,u,Nu,T);
ES = finrisk_ESpot(VaR,xi,beta,u);
    
end