function [LR_h,p_h] = finrisk_testVaR_h(hits,alpha,use_first_obs)
% FINRISK_TESTVAR_H performs a Christoffersen (1998) unconditional coverage 
%   test for series of VaR exceedances 
%  
% Syntax: [LR_h,p_h] = FINRISK_TESTVAR_H(hits,alpha,use_first_obs)
%
% Inputs:
%   hits          - vector of hits
%   alpha         - nominal significance level (exceedance probability)
%   use_first_obs - 'true' if first observation should be used, 
%                    else: 'false' (standard: 'true')
%
% Outputs: [LR_h,p_h] - test statistic and p value 
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

if nargin < 3
    use_first_obs = true;
end

if ~use_first_obs
    hits = hits(2:end);
end

a  = sum(hits);
T  = length(hits);
hr = sum(hits)/T;
LLalpha =  a * log(alpha) + (T-a) * log(1-alpha);
LLmle   =  a * log(hr) + (T-a) * log(1-hr);
LR_h = - 2 * (LLalpha - LLmle);
p_h = 1-chi2cdf(LR_h,1);
end