function [LR_i,p_i] = finrisk_testVaR_i(hits)
% FINRISK_TESTVAR_I performs an Christoffersen (1998) independency test
%   for a series of VaR hits (exceedances)
%
% Syntax: [LR_i,p_i] = finrisk_testVaR_i(hits)
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

T = length(hits);
a00 = 0;
a01 = 0;
a10 = 0;
a11 = 0;
for t=2:T
    if hits(t-1)==0 && hits(t) == 0
        a00 = a00+1;
    elseif hits(t-1)==0 && hits(t) == 1
        a01 = a01+1;
    elseif hits(t-1)==1 && hits(t) == 0
        a10 = a10+1;
    elseif hits(t-1)==1 && hits(t) == 1
        a11 = a11+1;
    else
        error('something is wrong');
    end
end
pi01 = a01/(a00+a01);
pi11 = a11/(a10+a11);
pi = (a01+a11)/(T-1);
LP0 = pi^(a01+a11) * (1-pi)^(a00+a10);
LP1 = pi01^a01 * (1-pi01)^a00 * pi11^a11 * (1-pi11)^a10;
LR_i = -2 * (log(LP0) - log(LP1));
p_i = 1-chi2cdf(LR_i,1);

end