function VaRvec = finrisk_dynVaRewma(alpha_in,pre_sample,sample,inc_mean)
% FINRISK_DYNVAREWMA calculates a series of Value at Risk estimates based on
%   EWMA volatility forecasts
%  
% Syntax: VaRvec = FINRISK_DYNVAREWMA(alpha_vec,pre_sample,sample,inc_mean)
%
% Inputs:
%   alpha_in   - significance level (exceedance probability)
%   pre_sample - observations used for estimation only
%   sample     - observations corresponding to VaR-forecasts and 
%                 used for later estimations       
% 
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

if size(alpha_in,1) > 1
    error('not implemented yet');
end

if nargin < 4
    inc_mean = false;
end

[sigvec,muvec] = finrisk_volewma(pre_sample,sample,inc_mean);
VaRvec(:,1) = muvec + sigvec * norminv(alpha_in);
end