function [sigvec,muvec] = finrisk_volewma(pre_sample,sample,inc_mean,T_roll)
% FINRISK_VOLEWMA calculates a series of volatility forecasts using EWMA
%
% Syntax: [sigvec,muvec] = FINRISK_VOLEWMA(pre_sample,sample,inc_mean,T_roll)
%
% Inputs:
%   pre_sample - observations used for estimation only
%   sample     - observations, for which volatilities are calculated
%   T_toll     - window length used for estimation 
%
% Outputs:
%   sigvec     - vector of volatility estimates
%   muvec      - vector of corresponding means
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2017/10/2

if nargin < 3
    inc_mean = false;
end

if nargin < 4
    T_roll = 250;
else
    if ~inc_mean, warning('T_roll is only used if mean is included'); end
end


lambda = 0.94;

T = length(sample);
sig2vec = zeros(T,1);
muvec   = zeros(T,1);
sig2vec(1)= var(pre_sample);

if ~inc_mean
    l2 = sample.^2;
    for t=1:T-1
        sig2vec(t+1) = lambda * sig2vec(t) + (1-lambda) * l2(t);
    end
else
    l_all = [pre_sample;sample];
    t0 = length(pre_sample);
    for t=1:T-1
        ind_start = t0+(t+1)-T_roll; % Bsp t=0: 1000 + 1 - 250 =  751;
        ind_end   = t0+(t+1)-1; % Bsp t=0: 1000 + 1 - 1   = 1000;
        l_m = l_all(ind_start:ind_end);
        muvec(t+1) = mean(l_m);
        sig2vec(t+1) = lambda * sig2vec(t) + (1-lambda) * (sample(t)-muvec(t+1))^2;
    end
end
sigvec = sqrt(sig2vec);
end