function [sig_vec,sig_pre,mu] = finrisk_volgarch(est_sample,pre_sample,sample,inc_mean)
% FINRISK_VOLGARCH calculates GARCH(1,1) volatility 
%
% Syntax: [sig_vec,sig_pre,mu] = FINRISK_VOLGARCH(est_sample,pre_sample,sample,inc_mean)
%
% Inputs:
%   est_sample - observations used for the model estimation
%   pre_sample - pre sample observations
%   sample     - observations for which forecasts are made
%   inc_mean   - include mean constant for estimated models
%
% Outputs:
%   sig_vec - volatility vector corresponding to sample data
%   sig_pre - volatility vector corresponding to pre sample
%   mu      - estimated mean constant
%
% See also: finrisk_est_garch, finrisk_volgarch_par
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

if nargin < 4
    inc_mean = true;
end

[alpha0,alpha1,beta1,mu] = finrisk_est_garch(est_sample,inc_mean);
[sig_vec,sig_pre] = finrisk_volgarch_par(pre_sample,sample,alpha0,alpha1,beta1,mu);
end