function sigvec = finrisk_volroll(pre_sample,sample,inc_mean,T_roll)
% FINRISK_VOLLROLL rolling calculation of standard volatility estimator
%
% Syntax: sigvec = FINRISK_VOLLROLL(pre_sample,sample,inc_mean,T_roll)
%
% Inputs:
%   pre_sample - pre sample observations
%   sample     - observations, for which volatilities are calculated
%   T_toll     - rolling period
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

if nargin < 3
    inc_mean = true;
end

if nargin < 4
    T_roll = 250;
end

sig2vec = zeros(length(sample),1);

t0 = length(pre_sample);
T = length(sample);

l_all = [pre_sample;sample];
l2_all = l_all.^2;

for t=0:T-1
    ind_start = t0+(t+1)-T_roll; % Bsp t=0: 1000 + 1 - 250 =  751;
    ind_end   = t0+(t+1)-1; % Bsp t=0: 1000 + 1 - 1   = 1000;
    
    if ~inc_mean
        l2_m = l2_all(ind_start:ind_end);
        sig2vec(t+1) = sum(l2_m)/T_roll;
    else
        l_m = l_all(ind_start:ind_end);
        sig2vec(t+1) = var(l_m);
    end
end

sigvec = sqrt(sig2vec);
end