function [ES,compES] = finrisk_pfES_vc(alpha_vec,w1,mu_vec,Sig_mat)
% FINRISK_PFES_VC variance covariance ES and its decomposition 
%   given mean vector and covariance matrix
%
% Syntax: [ES,compES] = FINRISK_PFES_VC(alpha_vec,w1,mu_vec,Sig_mat)
%
% See also: finrisk_pfES_vc_data
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

w2 = 1-w1;
muLp = w1 * mu_vec(1) + w2 * mu_vec(2);
varLp = w1^2 * Sig_mat(1,1) + w2^2 * Sig_mat(2,2) + 2*w1*w2*Sig_mat(1,2);
stdLp = sqrt(varLp);
ES = finrisk_ESpar(alpha_vec,'n',[muLp,stdLp]);

if nargout > 1
    compES = zeros(length(alpha_vec),2);
    for i=1:length(alpha_vec)
        covLpL1 = w1^2 * Sig_mat(1,1) + w1 * w2 * Sig_mat(1,2);
        covLpL2 = w2^2 * Sig_mat(2,2) + w1 * w2 * Sig_mat(1,2);
        compES1 = w1 * mu_vec(1) + covLpL1/varLp * (ES(i) - muLp);
        compES2 = w2 * mu_vec(2) + covLpL2/varLp * (ES(i) - muLp);
        compES(i,:) = [compES1 compES2];
        
        check = true;
        if check
            ES_const = normpdf(norminv(1-alpha_vec(i)))./alpha_vec(i);
            compES1_cp = w1 * mu_vec(1) + covLpL1/stdLp * ES_const;
            compES2_cp = w2 * mu_vec(2) + covLpL2/stdLp * ES_const;
        end
        if (compES1_cp-compES1) >1e-15 || abs(compES2_cp-compES2) > 1e-15
            error('something is wrong');
        end
    end
end
    
end