function [VaR,compVaR] = finrisk_pfVaR_vc(alpha_vec,w1,mu_vec,Sig_mat)
% FINRISK_PFVAR_VC calculates variance covariance VaR and its decomposition 
%   given the mean vector and the covariance matrix
%
% Syntax: [VaR,compVaR] = FINRISK_PFVAR_VC(alpha_vec,w1,mu_vec,Sig_mat)
%
% See also: finrisk_pfVaR_vc_data
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

w2 = 1-w1;
muLp = w1 * mu_vec(1) + w2 * mu_vec(2);
varLp = w1^2 * Sig_mat(1,1) + w2^2 * Sig_mat(2,2) + 2*w1*w2*Sig_mat(1,2);
stdLp = sqrt(varLp);
VaR = finrisk_VaRpar(alpha_vec,'n',[muLp,stdLp]);

if nargout > 1
    compVaR = zeros(length(alpha_vec),2);
    for i=1:length(alpha_vec)
        covLpL1 = w1^2 * Sig_mat(1,1) + w1 * w2 * Sig_mat(1,2);
        covLpL2 = w2^2 * Sig_mat(2,2) + w1 * w2 * Sig_mat(1,2);
        compVaR1 = w1 * mu_vec(1) + covLpL1/varLp * (VaR(i) - muLp);
        compVaR2 = w2 * mu_vec(2) + covLpL2/varLp * (VaR(i) - muLp);
        compVaR(i,:) = [compVaR1 compVaR2];
        
        check = true;
        if check
            compVaR1_cp = w1 * mu_vec(1) + covLpL1/stdLp * norminv(1-alpha_vec(i));
            compVaR2_cp = w2 * mu_vec(2) + covLpL2/stdLp * norminv(1-alpha_vec(i));
        end
        if abs(compVaR1_cp-compVaR1) > 1e-15 || abs(compVaR2_cp-compVaR2) > 1e-15
            error('something is wrong');
        end
    end
end
end