function [VaRl,VaRs] = finrisk_call_VaR_delta1(alpha,h,mu,s0,x,r,sigma,tau,incTheta)
% FINRISK_CALL_VaR_DELTA1 calculates a delta approximation for the VaR of a call position
%       (long/short) assuming normally distributed log returns 
%
% Syntax: [VaRl,VaRs] = FINRISK_CALL_VaR_DELTA1(alpha,h,mu,s0,x,r,sigma,tau,incTheta)
%
% Inputs/Outputs: see finrisk_call_VaR
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

version=1;

if nargin < 8
    error('not enough input arguments');
end

if nargin < 9
    incTheta = false;
end
DeltaC = finrisk_call_delta(s0,x,r,sigma,tau);
ThetaC = finrisk_call_theta(s0,x,r,sigma,tau);

if version == 1
    [msh,vsh] = finrisk_gbm_price_par(h,s0,mu,sigma);
    VaRl = - DeltaC * (exp(norminv(alpha,msh,vsh)) - s0);
    VaRs =   DeltaC * (exp(norminv(1-alpha,msh,vsh)) - s0);
else
    mh = (mu-1/2*sigma^2)*h;
    % Albrecht/Huggenberger: Finanzrisikomanagement, 2015, equation (4.4.44)
    VaRl = DeltaC * s0 * (1-exp(mh-norminv(1-alpha,0,1)*sigma*sqrt(h)));
    VaRs = DeltaC * s0 * (exp(mh+norminv(1-alpha,0,1) *sigma *sqrt(h))-1);
end

if incTheta
    VaRl = VaRl - ThetaC * h;
    VaRs = VaRs + ThetaC * h;
end
end
