function [VaRl,VaRs] = finrisk_call_VaR_delta2(alpha,h,mu,s0,x,r,sigma,tau,incTheta)
% FINRISK_CALL_VaR_DELTA2 calculates a delta approximation for the VaR of a call position
%       (long/short) assuming normally distributed discrete returns 
%
% Syntax: [VaRl,VaRs] = FINRISK_CALL_VaR_DELTA2(alpha,h,mu,s0,x,r,sigma,tau,incTheta)
%
% Inputs/Outputs: see finrisk_call_VaR
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

if nargin < 8
    error('not enough input arguments');
end

if nargin < 9
    incTheta = false;
end

DeltaC = finrisk_call_delta(s0,x,r,sigma,tau);
ThetaC = finrisk_call_theta(s0,x,r,sigma,tau);
mh = s0 * mu * h;
vh = s0 * sigma * sqrt(h);
% cp. Albrecht/Huggenberger: Finanzrisikomanagement, 2015 (4.4.45) or (4.4.42) with DeltaS ~ N(mh,vh)
VaRl = - DeltaC * (mh + vh * norminv(alpha,0,1));
VaRs =   DeltaC * (mh + vh * norminv(1-alpha,0,1));

if incTheta
    VaRl = VaRl - ThetaC * h;
    VaRs = VaRs + ThetaC * h;
end
end
