function [VaRl,VaRs] = finrisk_call_VaR_gamma(alpha,h,mu,s0,x,r,sigma,tau,incTheta)
% FINRISK_CALL_VAR_GAMMA calculates a Delta-Gamma-approximation for the VaR of a call position
%
% Syntax: [VaRl,VaRs] = FINRISK_CALL_VAR_GAMMA(alpha,h,mu,s0,x,r,sigma,tau,incTheta)
%
% Inputs/Outputs: see finrisk_call_VaR
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

if nargin < 8
    error('not enough input arguments');
end

if nargin < 9
    incTheta = false;
end

deltaC = finrisk_call_delta(s0,x,r,sigma,tau);
gammaC = finrisk_call_gamma(s0,x,r,sigma,tau);
thetaC = finrisk_call_theta(s0,x,r,sigma,tau);
muh = mu * h;
sigh = sigma * sqrt(h);
a = deltaC * muh * s0 + 1/2 * gammaC * s0^2 * muh^2;
b = deltaC * sigh * s0 + gammaC * s0^2 * sigh * muh;
c = gammaC * sigh^2 * s0^2;
qchia = ncx2inv(alpha,1,b^2/c^2);
VaRl = b^2/(2*c) - a - c/2 * qchia;

if nargout > 1
    qchi1ma = ncx2inv(1-alpha,1,b^2/c^2);
    VaRs = -b^2/(2*c) + a + c/2 * qchi1ma;
end

if incTheta
    VaRl = VaRl - thetaC * h;
    if nargout > 1
        VaRs = VaRs + thetaC * h;
    end
end
end