function price = finrisk_call_price(s,x,r,sigma,tau)
% FINRISK_CALL_PRICE calculates price of call option in the 
%       Black and Scholes model
%
% Syntax: price = FINRISK_CALL_PRICE(s,x,r,sigma,tau)
%
% Inputs:
%   s     - current price of the underlying
%   x     - strike price
%   r     - interest rate
%   sigma - volatility
%   tau   - time to maturity
%
% Revision: 1.1      Date: 2014/10/16

[d1,d2] = finrisk_d(s,x,r,sigma,tau);
price = s .* normcdf(d1,0,1) - x * exp(-r * tau) * normcdf(d2,0,1);
end