function [VaRl,VaRs] = finrisk_put_VaR_delta1(alpha,h,mu,s0,x,r,sigma,tau,incTheta)
% FINRISK_PUT_VaR_DELTA1 calculates a delta approximation for the VaR of a put position
%       (long/short) assuming normally distributed log returns
%
% Syntax: [VaRl,VaRs] = FINRISK_PUT_VaR_DELTA1(alpha,h,mu,s0,x,r,sigma,tau,incTheta)
%
% Inputs/Outputs: see finrisk_put_VaR
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

version = 1;

if nargin < 8
    error('not enough input arguments');
end

if nargin < 9
    incTheta = false;
end

DeltaP = finrisk_put_delta(s0,x,r,sigma,tau);
ThetaP = finrisk_put_theta(s0,x,r,sigma,tau);
if version==1
    [msh,vsh] = finrisk_gbm_price_par(h,s0,mu,sigma);
    VaRl = - DeltaP * (exp(norminv(1-alpha,msh,vsh)) - s0);
    VaRs =   DeltaP * (exp(norminv(alpha,msh,vsh)) - s0);
else
    disp('book version');
    m = (mu - 1/2*sigma^2);
    VaRl = -DeltaP * s0 * (exp(m * h + norminv(1-alpha,0,1)*sqrt(h)*sigma)-1);
    VaRs = -DeltaP * s0 * (1-exp(m*h + norminv(alpha,0,1)*sqrt(h)*sigma));
end

if incTheta
    VaRl = VaRl - ThetaP * h;
    VaRs = VaRs + ThetaP * h;
end
end
