function [VaRl,VaRs] = finrisk_put_VaR_delta2(alpha,h,mu,s0,x,r,sigma,tau,incTheta)
% FINRISK_PUT_VaR_DELTA2 calculates a delta approximation for the VaR of a put position
%       (long/short) assuming normally distributed discrete returns
%
% Syntax: [VaRl,VaRs] = FINRISK_PUT_VaR_DELTA2(alpha,h,mu,s0,x,r,sigma,tau,incTheta)
%
% Inputs/Outputs: see finrisk_put_VaR
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

    if nargin < 8 
        error('not enough input arguments');
    end
    
    if nargin < 9
       incTheta = false;
    end

    DeltaP = finrisk_put_delta(s0,x,r,sigma,tau);
    ThetaP = finrisk_put_theta(s0,x,r,sigma,tau);
    mh = s0 * mu * h;
    vh = s0 * sigma * sqrt(h);
    
    VaRl = - DeltaP * (mh + vh * norminv(1-alpha));
    VaRs =   DeltaP * (mh + vh * norminv(alpha));

    if incTheta
       VaRl = VaRl - ThetaP * h;
       VaRs = VaRs + ThetaP * h;
    end
    
end
