function [VaRl,VaRs] = finrisk_put_VaR_gamma(alpha,h,mu,s0,x,r,sigma,tau,incTheta)
% FINRISK_PUT_VAR_GAMMA calculates a delta-gamma-approximation of the VaR for a put position
%       (long/short) 
%
% Syntax: [VaRl,VaRs] = FINRISK_PUT_VAR_GAMMA(alpha,h,mu,s0,x,r,sigma,tau,incTheta)
%
% Inputs/Outputs: see finrisk_put_VaR
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

if nargin < 8
    error('not enough input arguments');
end

if nargin < 9
    incTheta = false;
end

deltaP = finrisk_put_delta(s0,x,r,sigma,tau);
gammaP = finrisk_put_gamma(s0,x,r,sigma,tau);
thetaP = finrisk_put_theta(s0,x,r,sigma,tau);
muh = mu * h;
sigh = sigma * sqrt(h);
a = deltaP * muh * s0 + 1/2 * gammaP * s0^2 * muh^2;
b = deltaP * sigh * s0 + gammaP * s0^2 * sigh * muh;
c = gammaP * sigh^2 * s0^2;
%   disp(c);
% very small c-values may lead to problems in ncx2inv
qchia = ncx2inv(alpha,1,b^2/c^2);
VaRl = b^2/(2*c) - a - c/2 * qchia;

if nargout > 1
    qchi1ma = ncx2inv(1-alpha,1,b^2/c^2);
    VaRs = -b^2/(2*c) + a + c/2 * qchi1ma;
end

if incTheta
    VaRl = VaRl - thetaP * h;
    if nargout > 1
        VaRs = VaRs + thetaP * h;
    end
end
end