function [VaRl,VaRs] = finrisk_put_VaR_sim(N,alpha_vec,h,mu,s0,x,r,sigma,tau,incTheta)
% FINRISK_PUT_VAR_SIM calculates VaR for put position based on Monte
% Carlo simulation
%
% Syntax: [VaRl,VaRs] = FINRISK_PUT_VAR_SIM(N,alpha_vec,h,mu,s0,x,r,sigma,tau,incTheta)
%
% Inputs:
%   N         - number of simulations
%   alpha_vec - significance levels (exceedance probability)
%   h         - risk horizon
%   mu        - drift parameter
%   s0        - current price of the underlying
%   x         - strike price
%   r         - interest rate
%   sigma     - volatility
%   tau       - time to maturity
%   incTheta  - if 'true' then time decay (theta) for VaR-period not 
%               considered. If 'false' then time decay 
%               considered.
%
% Outputs: [VaRl,VaRs] - Monte-Carlo-VaR for long and short position
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

    if nargin < 9 
       error('not enough input arguments');
    end

    if nargin < 10 
        incTheta = true;
    end

    Shsim = finrisk_gbm_price_rnd(N,h,s0,mu,sigma);
    Phsim = zeros(N,1);
    p0 = finrisk_put_price(s0,x,r,sigma,tau);
    
    if incTheta
        tauh = tau - h;
    else
        tauh = tau;
    end
    
    Phsim(:,1) = finrisk_put_price(Shsim,x,r,sigma,tauh);
   % for i=1:N
   %     Phsim(i,1) = finrisk_put_price(Shsim(i),x,r,sigma,tauh);
   % end
    
    Llong  = -(Phsim - p0);
    Lshort = -(p0 - Phsim);
    
    VaRl = finrisk_VaRemp(alpha_vec,Llong);
    VaRs = finrisk_VaRemp(alpha_vec,Lshort);
end