function price = finrisk_put_price(s,x,r,sigma,tau)
% FINRISK_PUT_PRICE calculates price of a put option in the 
%       Black and Scholes model
%
% Syntax: price = FINRISK_PUT_PRICE(s,x,r,sigma,tau)
%
% Inputs:
%   s     - current price of the underlying
%   x     - strike price
%   r     - interest rate
%   sigma - volatility
%   tau   - time to maturity
%
% Revision: 1.1      Date: 2014/10/16

[d1,d2] = finrisk_d(s,x,r,sigma,tau);
price = x * exp(- r * tau) * normcdf(-d2,0,1) - s .* normcdf(-d1,0,1);
end