function price = finrisk_put_price_black(f,x,r,sigma,tau)
% FINRISK_CALL_PRICE calculates price of call option in the 
%       Black and Scholes model
%
% Syntax: price = FINRISK_CALL_PRICE_BLACK(s,x,r,sigma,tau)
%
% Inputs:
%   f     - forward price 
%   x     - strike price
%   r     - interest rate
%   sigma - volatility
%   tau   - time to maturity
%
% Revision: 1.1      Date: 2015/12/19

debug = false;

d1 = (log(f./x) + (1/2 * sigma^2) * tau)/(sigma * sqrt(tau));
d2 = d1 - sigma * sqrt(tau);
price = exp(-r * tau) * (x .* normcdf(-d2,0,1) - f * normcdf(-d1,0,1));

if debug
   price_cp1 = finrisk_call_price_black(f,x,r,sigma,tau) + (x-f) * exp(- r* tau);
   price_cp2 = bsopt_put_price(f,x,r,sigma,tau,true);
   price_cp3 = bsopt_put_price(f,x,r,sigma,tau,true,1);

    if abs(price - price_cp1)>1e-10 || abs(price - price_cp2) > 1e-10 || abs(price - price_cp3) > 1e-10
        error('something is wrong');
    end
end
if max(~isreal(price))
    warning('nonreal pricing result. Something is wrong');
end

end