function VaRvec = finrisk_cpVaR_hfak(alpha_vec,PD,n,rho,E,typ_l)
% FINRISK_CPVAR_HFAK Numerical approximation for the VaR of a 
%   homogeneous credit portfolio with correlated defaults
%
% Syntax: VaRvec = FINRISK_CPVAR_HFAK(alpha_vec,PD,n,rho,E,typ_l)
%
% Inputs:
%   alpha_vec - vector wth exceedance probabilities/significance levels
%   PD        - default probability
%   n         - portfolio size
%   rho       - factor sensitivity/default correlation
%   E         - credit exposure
%   typ_l     - type of loss variable. '1' for D_p,n / '2' for L_p,n / '3' for 
%               barL_p,n
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16    

VaRvecD = zeros(length(alpha_vec),1);

if rho==0
    warning('rho = 0. using finrisk_cpVaR_hind');
    VaRvec = finrisk_cpVaR_hind(alpha_vec,PD,n,rho,E,1);
else
    % preestimate VaR using LHP to save computation time
    VaRDlhp = finrisk_cpVaR_lhpgran(alpha_vec,PD,n,rho,E,1);
    maxVaRD = max(VaRDlhp);
    Dmax   =  min(maxVaRD+20,n);
    Dvals   = (0:Dmax)';
    cdfvec  = finrisk_cpcdf_hfak(Dvals,PD,n,rho,E,1);
    
    for i=1:length(alpha_vec)
        alphai = alpha_vec(i);
        betai = 1-alphai;
        VaRi = find(cdfvec>=betai,1) - 1; %cdfvec(0) = P(D <=0) ==> - 1
        if isempty(VaRi)
            error('something is wrong');
        end
        VaRvecD(i) = VaRi;
    end
    
    VaRvec = finrisk_cp_transDx(VaRvecD,n,E,typ_l);
end
end