function VaRvec = finrisk_cpVaR_hfaksim(alpha_vec,Nsim,PD,n,rho,E,typ_l,typ_am,xpar)
% FINRISK_CPVAR_HFAKSIM Monte Carlo approximation to the VaR from a 
%   homogeneous credit portfolio with correlated defaults
%
% Syntax: VaRvec = FINRISK_CPVAR_HFAKSIM(alpha_vec,Nsim,PD,n,rho,E,typ_l,typ_am,xpar)
%
% Inputs:
%   alpha_vec - vector wth exceedance probabilities/significance levels
%   Nsim      - number of simulations
%   PD        - default probability
%   n         - portfolio size
%   rho       - factor sensitivity/default correlation
%   E         - credit exposure
%   typ_l     - type of loss variable. '1' for D_p,n / '2' for L_p,n / '3' for 
%               barL_p,n
%   typ_am    - distributional assumption for the asset model
%               'mvn1', 'mvn2', 'mvn3' different implementations of the
%               standard factor model based on a multivariate normal
%               distribution (use mvn3)
%               'tcop1', 'tcop2' different implementations of the factor
%               model based on a t copula (use tcop2)
%   xpar      - degrees of freedom parameter for t copula models
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16    

if nargin < 5
    error('not enough input arguments');
end

if nargin < 6
    E = 1;
end

if nargin < 7
    typ_l = 1;
end

if nargin < 8
    typ_am = 'mvn3';
end

if nargin < 9
    xpar = [];
end

l_vec = finrisk_cprnd_hfak(Nsim,PD,n,rho,E,typ_l,typ_am,xpar);
VaRvec = finrisk_VaRemp(alpha_vec,l_vec);

end