function VaRvec = finrisk_cpVaR_hindnv(alpha_vec,PD,n,E,typ_l)
% FINRISK_CPVAR_HINDNV calculates the VaR for a homogeneous credit portfolio with
%       independent defaults based on normal approximation
%
% Syntax: VaRvec = FINRISK_CPVAR_HINDNV(alpha_vec,PD,n,E,typ_l)
%
% Inputs:
%   alpha_vec - vector of significance levels/exceedance probabilities
%   PD        - default probability
%   n         - portfolio size
%   E         - credit exposure
%   typ_l     - type of loss variable. '1' for D_p,n / '2' for L_p,n / '3' for
%               barL_p,n
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

if nargin < 3
    error('not enough input arguments');
end

if nargin < 4
    E = 1;
end

if nargin < 5
    typ_l = 1;
end
ELn = PD *n;
varLn = n * PD * (1-PD);
VaRnvD = norminv(1-alpha_vec,ELn,sqrt(varLn));

switch typ_l
    case 1
        VaRvec = VaRnvD;
    case 2
        VaRvec = E * VaRnvD;
    case 3
        VaRvec = VaRnvD/n;
end

%    VaRnvD = round(norminv(1-alpha_vec,ELn,sqrt(varLn)));
%    VaRvec = finrisk_cp_transDx(VaRnvD,n,E,typ_l);
end