function VaRvec = finrisk_cpVaR_lhpgran(alpha_vec,PD,n,rho,E,typ_l)
% FINRISK_CPVAR_LHPGRAN Asymptotic approximation to the VaR from a homogeneous
%   credit portfolio with correlated defaults including a granularity
%   adjustment 
%
% Syntax: VaRvec = FINRISK_CPVAR_LHPGRAN(alpha_vec,PD,n,rho,E,typ_l)
%
% Inputs:
%   alpha_vec - vector wth exceedance probabilities/significance levels
%   PD        - default probability
%   n         - portfolio size
%   rho       - factor sensitivity/default correlation
%   E         - credit exposure
%   typ_l     - type of loss variable. '1' for D_p,n / '2' for L_p,n / '3' for 
%               barL_p,n
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16    
    

    if nargin < 5
        E = 1;
    end
    
    if nargin < 6
        typ_l = 1;
    end
    
    if rho == 0 
        error('rho = 0');
    end

    Q = normcdf((norminv(PD)+sqrt(rho)*norminv(1-alpha_vec))/sqrt(1-rho));
    GA = 1/2 * ...
            (Q.*(1-Q)./normpdf(norminv(Q)) ...
              .* (sqrt((1-rho)/rho).*norminv(1-alpha_vec)-norminv(Q)) ...
              + 2 .* Q - 1);
    VaRveclbar = Q + 1/n * GA;
          
    switch typ_l
        case 1
            VaRvec = n * VaRveclbar;
        case 2
            VaRvec = n * E * VaRveclbar;
        case 3
            VaRvec = VaRveclbar;
    end
end