function LVaR = finrisk_cpVaR_poiss(alpha_vec,PD,n,E,typ_l)
% FINRISK_CPVAR_POISS calculates the VaR for a homogeneous credit portfolio with
%       independent defaults based on a Poisson approximation
%
% Syntax: LVaR = FINRISK_CPVAR_POISS(alpha_vec,PD,n,E,typ_l)
%
% Inputs:
%   alpha_vec - probability level
%   PD        - default probability
%   n         - portfolio size
%   E         - credit exposure
%   typ_l     - type of loss variable. '1' for D_p,n / '2' for L_p,n / '3' for
%               barL_p,n
%
% See also poissinv, finrisk_cp_transDx
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

if nargin < 4
    E = 1;
end

if nargin < 5
    typ_l = 1;
end

lambda_n = n * PD;

DVaR = poissinv(1-alpha_vec,lambda_n);
LVaR = finrisk_cp_transDx(DVaR,n,E,typ_l);
end