function pvec = finrisk_cpcdf_hfak(xvec,PD,n,rho,E,typ_l)
% FINRISK_CPPDF_HFAK Numerical approximation to the exact cumulative
%   distribution function of the loss from a homogeneous credit portfolio 
%   with correlated defaults
%
% Syntax: pvec = FINRISK_CPCDF_HFAK(xvec,PD,n,rho,E,typ_l)
%
% Inputs:
%   xvec  - value of loss variable
%   PD    - default probability
%   n     - portfolio size
%   rho   - factor sensitivity
%   E     - credit exposure
%   typ_l - type of loss variable. '1' for D_p,n / '2' for L_p,n / '3' for 
%           barL_p,n
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16    


    if nargin < 5
        E = 1;
    end
    
    if nargin < 6
        typ_l = 1;
    end

    Dvec = finrisk_cp_transxD(xvec,n,E,typ_l);    
    pvec = zeros(length(xvec),1);
    Dmax = max(Dvec);
    Dsort = (0:Dmax)';
    pDsort = finrisk_cppdf_hfak(Dsort,PD,n,rho,E,1);
    
    for i=1:length(Dvec)
        d = Dvec(i);
        pos = find(Dsort==d,1);
        pvec(i) = sum(pDsort(1:pos));
    end
end