function pvec = finrisk_cpcdf_hindnv(xvec,PD,n,E,typ_l)
% FINRISK_CPCDF_HINDNV Normal approximation of the cumulative distribution
%       function for the loss from homogeneous credit portfolio with 
%       independent defaults
%
% Syntax: pvec = FINRISK_CPCDF_HINDNV(xvec,PD,n,E,typ_l)
%
% Inputs: 
%   xvec  - value of loss variable
%   PD    - default probability
%   n     - portfolio size
%   E     - credit exposure
%   typ_l - type of loss variable. '1' for D_p,n / '2' for L_p,n / '3' for
%           barL_p,n
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

if nargin < 3
    error('not enough input arguments');
end

if nargin < 4
    E = 1;
end

if nargin < 5
    typ_l = 1;
end

Dvec = finrisk_cp_transxD(xvec,n,E,typ_l);

ELn = PD *n;
varLn = n * PD * (1-PD);

pvec = normcdf(Dvec,ELn,sqrt(varLn));
end
