function pvec = finrisk_cpcdf_poiss(xvec,PD,n,E,typ_l)
% FINRISK_CPCDF_POISS Poisson approximation for the cumulative distribution
%       function of the loss of homogeneous credit portfolio 
%       with independent defaults
%
% Syntax: pvec = FINRISK_CPCDF_POISS(xvec,PD,n,E,typ_l)
%
% Inputs:
%   xvec  - value of loss variable
%   PD    - default probability
%   n     - portfolio size
%   E     - credit exposure
%   typ_l - type of loss variable. '1' for D_p,n / '2' for L_p,n / '3' for
%           barL_p,n
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

if nargin < 4
    E = 1;
end

if nargin < 5
    typ_l = 1;
end

lambda_n = n * PD;
Dvec = finrisk_cp_transxD(xvec,n,E,typ_l);
pvec = poisscdf(Dvec,lambda_n);
end