function pvec = finrisk_cppdf_hfak(xvec,PD,n,rho,E,typ_l)
% FINRISK_CPPDF_HFAK Numerical approximation to the exact mass function of 
%   the loss from a homogeneous credit portfolio with correlated defaults
%
% Syntax: pvec = FINRISK_CPPDF_HFAK(xvec,PD,n,rho,E,typ_l)
%
% Inputs:
%   xvec  - value of loss variable
%   PD    - default probability
%   n     - portfolio size
%   rho   - factor sensitivity
%   E     - credit exposure
%   typ_l - type of loss variable. '1' for D_p,n / '2' for L_p,n / '3' for 
%           barL_p,n
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16    

if nargin < 5
    E = 1;
end

if nargin < 6
    typ_l = 1;
end


Dvec = finrisk_cp_transxD(xvec,n,E,typ_l);

H = norminv(PD);

pvec = zeros(length(xvec),1);
for i=1:length(xvec)
    Dval = Dvec(i);
    intfun = @(x) finrisk_cpcpdf_hfak(Dval,x) * 1/sqrt(2*pi) .* exp(-x.^2/2);
    pvec(i) = integral(intfun,-Inf,+Inf);
end

% 5.2.37 und 5.2.38
    function pvec = finrisk_cpcpdf_hfak(d,fvec)
        PDfvec = normcdf((H-sqrt(rho)*fvec)/sqrt(1-rho));
        pvec = zeros(size(fvec,1),size(fvec,2));
        for c=1:length(fvec)
            pvec(c) = binopdf(d,n,PDfvec(c));
        end
    end

end