function pvec = finrisk_cppdf_lhp(xvec,PD,n,rho,E,typ_l)
% FINRISK_CPPDF_LHP Asymptotic approximation to the mass function of 
%   the loss from a homogeneous credit portfolio with correlated defaults
%
% Syntax: pvec = FINRISK_CPPDF_LHP(xvec,PD,n,rho,E,typ_l)
%
% Inputs:
%   xvec  - value of loss variable
%   PD    - default probability
%   n     - portfolio size
%   rho   - factor sensitivity/default correlation
%   E     - credit exposure
%   typ_l - type of loss variable. '1' for D_p,n / '2' for L_p,n / '3' for 
%           barL_p,n
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16    

    if nargin < 3
        error('not enough input arguments');
    end
    
    if nargin < 6
        typ_l = 3;
    end
    
    switch typ_l
        case 1
            lbar = xvec/n;
        case 2
            lbar = xvec/(E*n);
        case 3
            lbar = xvec;
    end
    
    pvec = sqrt((1-rho)/rho) * ...
               exp(...
                  1/2 * norminv(lbar).^2 - 1/(2*rho) ...
                  .* (sqrt(1-rho).* norminv(lbar) - norminv(PD)).^2);

    %pvec2 = sqrt((1-rho)/rho) ...
    %    .* exp ( ...
    %          1/2 .* (norminv(lbar,0,1)).^2 ...
    %         -1/(2 .* rho) ...
    %               .* (sqrt(1-rho) .* norminv(lbar) - norminv(PD,0,1)).^2 ...
    %          );              
          
    %if abs(pvec-pvec2)>0
    %    disp(abs(pvec-pvec2));
    %    error('something is wrong');
    %end
end