function [alpha0,alpha1,beta1,mu] = finrisk_est_garch(dat,est_mean,show_info,est_meth)
% FINRISK_EST_GARCH interface to Matlab GARCH model estimation
%  
% Syntax: [alpha0,alpha1,beta1,mu] = FINRISK_EST_GARCH(dat,est_mean,show_info)
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2015/08/20


if nargin < 2
    est_mean = true;
end

if nargin < 3
    show_info = false;
end

if nargin < 4
   est_meth = 1; 
end

if est_meth == 1
    mu_mean = true; % set mu equal to sample mean
    use_mfe = false;
else
    mu_mean = true; % set mu equal to sample mean
    use_mfe = true;
end    


if ~use_mfe
    if show_info, disp('Running Matlab MLE'); end
    if est_mean
        if mu_mean
            mu = mean(dat);
            dat = dat - mu;
            mod = garch(1,1);
            optOptions = optimoptions(@fmincon,'MaxIter',1000,'MaxFunEvals',1000);            
        else
            %optOptions = optimoptions(@fmincon,'TolCon',1e-8,'Algorithm','sqp','MaxIter',2000,'MaxFunEvals',3000);
            optOptions = optimoptions(@fmincon,'TolCon',1e-8,'Algorithm','sqp','MaxIter',5000,'MaxFunEvals',8000);
            mod = garch('Offset',NaN,'GARCHLags',1,'ARCHLags',1);
        end
    else
        mod = garch(1,1);
    end
    [mod,~,~,info] = mod.estimate(dat,'Display','off','Offset',mean(dat),'Options',optOptions);
    alpha0 = mod.Constant;
    alpha1 = mod.ARCH{1};
    beta1  = mod.GARCH{1};
    if ~mu_mean
        mu = mod.Offset;
    end
    if info.exitflag <= 0
        warning('MLE not succesful');
    elseif show_info
        disp('Sch�tzung erfolgreich. Sch�tzergebnisse');
        disp(['alpha0 = ',num2str(alpha0),', alpha1 = ',num2str(alpha1),...
            ', beta1 = ',num2str(beta1),' mu = ',num2str(mu*100),'%']);
    end
else
    if show_info, disp('Using MFE toolbox'); end
    mfe_opt  =  optimset('fminunc');
    mfe_opt  =  optimset(mfe_opt , 'TolFun'      , 1e-005);
    mfe_opt  =  optimset(mfe_opt , 'TolX'        , 1e-005);
    mfe_opt  =  optimset(mfe_opt , 'Display'     , 'notify');
    mfe_opt  =  optimset(mfe_opt , 'Diagnostics' , 'off');
    mfe_opt  =  optimset(mfe_opt , 'LargeScale'  , 'off');
    mfe_opt  =  optimset(mfe_opt , 'MaxFunEvals' , 400*(1+1+1+2));
    
    dist_mfe = 'NORMAL';
    
%    switch res_dist_garch
%        case 'n'
%        case 'tstd'
%            dist_mfe = 'STUDENTST';
%        case 'st'
%            dist_mfe = 'SKEWT';
%        otherwise
%            error('res_dist not implemented by mfetoolbox');
%    end

    if est_mean
        if ~mu_mean
            error('not implemented with mfe');
        end
        mu = mean(dat);
    else
        mu = 0;
    end
    eps_data = dat - mu;
    p_mfe = 1; %check?
    q_mfe = 1;
    par_mfe = tarch(eps_data,p_mfe,0,q_mfe,dist_mfe,[],[],mfe_opt);
    alpha0 = par_mfe(1);
    alpha1 = par_mfe(2);
    beta1  = par_mfe(3);
end

end