function [mu,sig,g,h] = finrisk_est_gh(dat,meth,estls)
% FINRISK_EST_GH estimates the parameters of a standardized gh-distribution
%  
% Syntax: 
%   [mu,sig,g,h] = FINRISK_EST_GH(dat) 
%
% Inputs:
%   dat    - vector with input-data
%
% Outputs:
%   mu      - estimated location parameter 
%   sig     - estimated standard deviation
%   g       - estimated skewness parameter
%   h       - estimated kurtosis parameter
%
% author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2015/09/09

    if nargin < 3
        estls = true;
    end
        

    if nargin < 2 || isempty(meth)
        meth = 4;
    end

    if estls
        mu  = mean(dat);
        sig = std(dat);
    else
        mu = 0;
        sig = 1;
    end
    
    zdat = (dat-mu)./sig;
    par = ghstd_est(zdat,meth,false);
    g = par(1);
    h = par(2);
end