function [xi,beta,u,Nu,T] = finrisk_est_pot(ldat,threshold)
% FINRISK_EST_POT estimates the parameters necessary for 
%   POT-VaR calculation 
%  
% Syntax: [xi,beta,u,Nu,T] = FINRISK_EST_POT(ldat,threshold) 
%
% Inputs:
%   ldat      - loss data for estimation 
%   threshold - threshold used for estimation 
%
% Outputs:
%   xi   - shape parameter of GPD
%   beta - scale parameter of GPD
%   u    - threshold
%   Nu   - number of peaks 
%   T    - total number of iid observations
% 
% See also: gpfit, finrisk_VaRpot_data, finrisk_VaRpot
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

if nargin < 2
    u = quantile(ldat,0.9);
else
    u = threshold;
end
T = length(ldat);
peaks = ldat(ldat>u);
Nu = length(peaks);
ex = peaks - u;
par = gpfit(ex);
xi = par(1);
beta = par(2);

if xi == 0
    error('gpd shape parameter is zero');
end

end