function [mu,sig,nu,lam] = finrisk_est_st(dat,estls)
% FINRISK_EST_ST estimates the four-parameter skewed t-distribution
%  
% Syntax: 
%   [mu,sig,nu,lam] = FINRISK_EST_ST(dat) 
%
% Inputs:
%   dat    - vector with input-data
%
% Outputs:
%   mu      - estimated location parameter 
%   sig     - estimated standard deviation
%   nu      - estimated degrees of freedom
%   lam     - estimated skewness parameter
%
% author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2015/09/09

if nargin < 2
    estls = true;
end

if estls
    mu  = mean(dat);
    sig = std(dat);
else
    mu = 0;
    sig = 1;
end

zdat = (dat-mu)./sig;
par = st_est(zdat,1,false);
nu = par(1);
lam = par(2);
end