function [mu,sig,nu] = finrisk_est_tstd(dat,estls)
% FINRISK_EST_ST estimates the three-parameter standardized t-distribution
%  
% Syntax: 
%   [mu,sig,nu] = FINRISK_EST_TSTD(dat,estls) 
%
% Inputs:
%   dat    - vector with input-data
%   estls  - estimate location and scale parameters
%
% Outputs:
%   mu      - estimated location parameter 
%   sig     - estimated standard deviation
%   nu      - estimated degrees of freedom
%
% author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2015/09/09

if nargin < 2
    estls = true;
end

if estls
    mu  = mean(dat);
    sig = std(dat);
else
    mu = 0;
    sig = 1;
end

zdat = (dat-mu)./sig;
par = tstd_est(zdat,1,false);
nu = par(1);
end