function ltd = finrisk_ltd_emp(xvec,yvec,alpha)
% FINRISK_LTD_EMP calculates an empirical LTD-estimate
%
% Syntax: ltd = FINRISK_LTD_EMP(xvec,yvec,alpha)
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

version = 1;

T = length(xvec);

if nargin < 3
    alpha = 1/sqrt(T);
end


if version == 1
    xvecs = sort(xvec);
    yvecs = sort(yvec);
    pos = ceil(alpha*T); % corresponds to lower (!) quantile
    qx = xvecs(pos);
    qy = yvecs(pos);
    nom = sum((xvec<=qx) .* (yvec<qy)); % joint prob * T
    denom = sum(yvec <= qy);            % marginal prob * T
    ltd = nom/denom;                    % conditional prob
elseif version == 2
    %
    u1 = finrisk_ecdf(xvec,xvec,length(xvec));
    u2 = finrisk_ecdf(yvec,yvec,length(yvec));
    
    Calpha = fin913_mvecdf([alpha,alpha]',u1,u2);
    ltd = Calpha/alpha;
else
    error('version not implemented');
end
end