function meta_par = finrisk_meta_est(l1,l2,marg_type,copula_type)
% FINRISK_META_EST estimates parameters of a bivariate meta distribution 
%       given observations of two loss variables
%
% Syntax: meta_par = FINRISK_META_EST(l1,l2,marg_type,copula_type)
%
% Inputs: 
%   l1          - loss vector first margin
%   l2          - loss vector second margin
%   marg_type   - type of marginal distributions
%   copula_type - type of the copula 
%
% Outputs:
%   meta_par    - structure with the fields
%                   marg_type 
%                   copula_type
%                   m1_par
%                   m2_par
%                   copula_par
%
% See also: finrisk_meta_sim, finrisk_pfVaR_metasim
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16
    
% margin est
meta_par.marg_type = marg_type;
switch marg_type
    case 'nv'
        meta_par.m1_par = [mean(l1),std(l1)];
        meta_par.m2_par = [mean(l2),std(l2)];
    case 't'
        [mu1,std1,nu1] = finrisk_est_t(l1,'mle');
        [mu2,std2,nu2] = finrisk_est_t(l2,'mle');
        meta_par.m1_par = [mu1 std1 nu1];
        meta_par.m2_par = [mu2 std2 nu2];
end

% copula est
u1 = finrisk_ecdf(l1,l1,length(l1)+1);
u2 = finrisk_ecdf(l2,l2,length(l2)+1);
meta_par.copula_type = copula_type;
switch copula_type
    case {'Gaussian','nv'}
        rhomat = copulafit('Gaussian',[u1 u2]);
        meta_par.copula_par = rhomat(2,1);
    case 't'
        [rhomat,nucop] = copulafit('t',[u1 u2]);
        meta_par.copula_par = [rhomat(2,1) nucop];
end
    
end