function lmat = finrisk_meta_sim(meta_par,Nsim)
% FINRISK_META_SIM simulation from a meta distribution
%
% Syntax: lmat = FINRISK_META_SIM(meta_par,Nsim)
%
% See also: finrisk_meta_est, finrisk_pfVaR_metasim
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

% sim umat = [u1 u2] from copula
switch meta_par.copula_type
    case {'Gaussian','nv'}
        rho = meta_par.copula_par(1);
        umat = copularnd('Gaussian',rho,Nsim);
    case 't'
        rho = meta_par.copula_par(1);
        nu_cop = meta_par.copula_par(2);
        umat = copularnd('t',rho,nu_cop,Nsim);
    otherwise
        error('copula type not implemented');
end

% transform umat according to marginal distributions
switch meta_par.marg_type
    case 'nv'
        mu1    = meta_par.m1_par(1);
        sigma1 = meta_par.m1_par(2);
        mu2    = meta_par.m2_par(1);
        sigma2 = meta_par.m2_par(2);
        l1 = norminv(umat(:,1),mu1,sigma1);
        l2 = norminv(umat(:,2),mu2,sigma2);
    case 't'
        mu1    = meta_par.m1_par(1);
        std1   = meta_par.m1_par(2);
        nu1    = meta_par.m1_par(3);
        mu2    = meta_par.m2_par(1);
        std2   = meta_par.m2_par(2);
        nu2    = meta_par.m2_par(3);
        c_nu1 = sqrt((nu1-2)/nu1);
        c_nu2 = sqrt((nu2-2)/nu2);
        l1    = mu1 + std1 * c_nu1 * tinv(umat(:,1),nu1);
        l2    = mu2 + std2 * c_nu2 * tinv(umat(:,2),nu2);
end
lmat = [l1 l2];
end