function utd = finrisk_utd_emp(xvec,yvec,alpha)
% FINRISK_UTD_EMP calculates an empirical UTD-estimator
%
% Syntax: utd = FINRISK_UTD_EMP(xvec,yvec,alpha)
%
% Author: Markus Huggenberger (huggenberger@bwl.uni-mannheim.de)
% Revision: 1.1      Date: 2014/10/16

T = length(xvec);

if nargin < 3
    alpha = 1/sqrt(T);
end

xs = sort(xvec);
ys = sort(yvec);
pos = ceil((1-alpha)*T); % corresponds to lower quantile
if pos == T
    error('alpha too large P(L2 > Q)=0');
end
qx = xs(pos);
qy = ys(pos);
nom = sum((xvec > qx) .* (yvec > qy)); % joint prob * T
denom = sum((yvec > qy)); % marginal prob * T
utd = nom/denom; % conditional prob * T
end