
fprintf('\n\n*** Ex1: Value at Risk estimation ***\n\n');

% check path
if  exist('finrisk_VaRpar','file')==0
    error('finrisk_VaRpar not found. Please run finrisk_add_path.m.');
end

%% settings
loss_typ = 3;     % type of the loss distribution 
                  %   1 = normal distribution
                  %   2 = t-distribution 
                  %   3 = mixture distribution

N_losses = 1000;  % size of the random sample 

alpha_VaR = 0.025; % significance level for VaR 

loss_vec = ex_sim_losses(loss_typ,N_losses); % generate loss sample 


%% VaR estimations
fprintf('\nApplying selected VaR-estimators:\n\n');

% parametric
VaR_n  = finrisk_VaRpar_data(alpha_VaR,'n',loss_vec);
fprintf('  Parametric VaR (normal distr)   = %.2f %%\n',VaR_n*100);

VaR_t   = finrisk_VaRpar_data(alpha_VaR,'t',loss_vec);
fprintf('  Parametric VaR (t distr) \t  = %.2f %%\n',VaR_t*100);

warning off;
nrep_est = 3;
VaR_mix = finrisk_VaRmix_data(alpha_VaR,loss_vec,nrep_est);
warning on;
fprintf('  Parametric VaR (normal mixture) = %.2f %%\n',VaR_mix*100);
fprintf('  (used only 3 runs of the EM-algorithm, increase nrep_est to obtain more reliable results.)\n\n');

% semi parametric
VaR_cf  = finrisk_VaRcf_data(alpha_VaR,loss_vec);
fprintf('  Cornish Fisher VaR \t\t  = %.2f %%\n',VaR_cf*100);

VaR_pot = finrisk_VaRpot_data(alpha_VaR,loss_vec);
fprintf('  Peaks over Threshold VaR \t  = %.2f %%\n\n',VaR_pot*100);


% non parametric 
VaR_e   = finrisk_VaRemp(alpha_VaR,loss_vec);
fprintf('  Empirical VaR \t\t  = %.2f %%\n',VaR_e*100);


%% 
fprintf('\n***   end of Ex1   *** \n\n\n');
