fprintf('\n\n*** Ex2: Expected Shortfall estimation ***\n\n');

% check path
if  exist('finrisk_ESpar','file')==0
    error('finrisk_ESpar not found. Please run finrisk_add_path.m.');
end

%% settings
loss_typ = 3;     % type of the loss distribution 
                  %   1 = normal distribution
                  %   2 = t-distribution 
                  %   3 = mixture distribution

N_losses = 1000;  % size of the random sample 

alpha_ES = 0.025; % significance level for ES 

loss_vec = ex_sim_losses(loss_typ,N_losses); % generate loss sample 


%% VaR estimations
fprintf('\nApplying selected ES-estimators:\n\n');

% parametric
ES_n  = finrisk_ESpar_data(alpha_ES,'n',loss_vec);
fprintf('  Parametric ES (normal distr) \t = %.2f %%\n',ES_n*100);

ES_t   = finrisk_ESpar_data(alpha_ES,'t',loss_vec);
fprintf('  Parametric ES (t distr) \t = %.2f %%\n',ES_t*100);

warning off;
nrep_est = 3;
ES_mix = finrisk_ESmix_data(alpha_ES,loss_vec,nrep_est);
warning on;
fprintf('  Parametric ES (normal mixture) = %.2f %%\n',ES_mix*100);
fprintf('  (used only 3 reestimations, increase nrep_est to obtain more reliable estimates\n\n');

% semi parametric
ES_cf  = finrisk_EScf_data(alpha_ES,loss_vec);
fprintf('  Cornish Fisher ES \t\t = %.2f %%\n',ES_cf*100);

ES_pot = finrisk_ESpot_data(alpha_ES,loss_vec);
fprintf('  Peaks over Threshold ES \t = %.2f %%\n\n',ES_pot*100);


% non parametric 
ES_e   = finrisk_ESemp(alpha_ES,loss_vec);
fprintf('  Empirical ES \t\t\t = %.2f %%\n',ES_e*100);

CVaR1_e   = finrisk_CVaRemp1(alpha_ES,loss_vec);
fprintf('  Empirical upper CVaR \t\t = %.2f %%\n',CVaR1_e*100);

CVaR2_e   = finrisk_CVaRemp2(alpha_ES,loss_vec);
fprintf('  Empirical lower CVaR \t\t = %.2f %%\n',CVaR2_e*100);

%% 
fprintf('\n***   end of Ex2   *** \n\n\n');


