fprintf('\n\n*** Ex7: Value at Risk homogeneous credit portfolio ***\n\n');

% check path
if  exist('finrisk_cpVaR_hfak','file')==0
    error('finrisk_cpVaR_hfak not found. Please run finrisk_add_path.m.');
end

%% common settings
    fprintf('   common settings\n');

    alpha_VaR = 0.005;      % VaR significance level (exceedance probability)
    PD        = 0.0005;     % probability of default
    n         = 100;        % porfolio size
    E         = 1;          % exposure height    
    typ_l     = 3;          % loss type = relative
    
    fprintf('   PD: %.2f %%\n',PD*100);
    fprintf('   n: %d     \n',n);
    fprintf('   alpha VaR: %.2f %%\n\n',alpha_VaR*100);

%% a) homogeneous credit portfolio with independent defaults

    fprintf('a) independent defaults\n');
    
    VaR1 = finrisk_cpVaR_hind(alpha_VaR,PD,n,E,typ_l);
    VaR2 = finrisk_cpVaR_hindnv(alpha_VaR,PD,n,E,typ_l);
    
    fprintf('   exact  VaR:                    %.2f %%\n',VaR1*100); 
    fprintf('   normal VaR approximation:      %.2f %%\n',VaR2*100);
    
    
%% b) homogeneous credit portfolio with correlated defaults
    fprintf('\nb) correlated factor model with mvn dist\n');

    rho = 0.2;
    fprintf('   rho: %.2f\n\n',rho);

    VaR3 = finrisk_cpVaR_hfak(alpha_VaR,PD,n,rho,E,typ_l);                        
    VaR4 = finrisk_cpVaR_lhp(alpha_VaR,PD,n,rho,E,typ_l);
    VaR5 = finrisk_cpVaR_lhpgran(alpha_VaR,PD,n,rho,E,typ_l);
    
    fprintf('   exact  VaR:                    %.2f %%\n',VaR3*100); 
    fprintf('   LHP VaR approx.:               %.2f %%\n',VaR4*100);    
    fprintf('   LHP VaR approx. + granularity: %.2f %%\n',VaR5*100);    

    
 %% c) homogeneous credit portfolio with correlated defaults and t copula   
    fprintf('\nc) correlated factor model -- mvn dist vs. t-copula\n');
     
    Nsim = 100000;
    nu_t  = 5;
    
    fprintf('   nu (t-copula): %.2f\n',nu_t);
    fprintf('   number of simulations: %d\n\n',Nsim);
     
    VaR6   = finrisk_cpVaR_hfaksim(alpha_VaR,Nsim,PD,n,rho,E,typ_l,'mvn3');                            
    VaR7   = finrisk_cpVaR_hfaksim(alpha_VaR,Nsim,PD,n,rho,E,typ_l,'tcop2',nu_t);                        

    fprintf('   simulated VaR (mvn):          %.2f %%\n',VaR6*100); 
    fprintf('   simulated VaR (t-cop):        %.2f %%\n',VaR7*100);    
    
 %%
    fprintf('\n***   end of Ex7  *** \n\n\n');
