function losses = ex_sim_losses(typ_sim,Nsim)
% ES_SIM_LOSSES simulates loss samples for the examples
%
% Syntax: losses = EX_SIM_LOSSES(typ_sim,Nsim)

switch typ_sim
    case 1
        fprintf('Creating example loss data from a normal distribution...\n');        
        muL = -0.1/12;
        stdL = 0.25/sqrt(12);
        losses = normrnd(muL,stdL,Nsim,1);
    case 2
        fprintf('Creating example loss data from a t-distribution...\n');
        muL  = -0.1/12;
        stdL = 0.25/sqrt(12);
        nuL  = 5;
        losses  =  muL + stdL * sqrt((nuL-2)/nuL) * trnd(nuL,Nsim,1);
    case 3
        fprintf('Creating example loss data from a mixture distribution...\n');
        mu_c(1,1)    = 0.3/12;
        mu_c(2,1)    = -0.15/12;
        Sig_c(1,1,1) = (0.4/sqrt(12))^2;
        Sig_c(1,1,2) = (0.2/sqrt(12))^2;
        p_c          = [0.15 0.85];
        gmd = gmdistribution(mu_c,Sig_c,p_c);
        losses = gmd.random(Nsim);
    otherwise
        error('typ_sim must be in {1,2,3}');
end
fprintf('  Done.\n\n');

end




